# phono3py
A simulation package of phonon-phonon interaction related properties. Phono3py user documetation is found at http://phonopy.github.io/phono3py/.

## Mailing list for questions

Usual phono3py questions should be sent to phonopy mailing list (https://sourceforge.net/p/phonopy/mailman/).

## Development

The development of phono3py is managed on the `develop` branch of github phono3py repository.

* Github issues is the place to discuss about phono3py issues.
* Github pull request is the place to request merging source code.

## Documentation

Phono3py user documetation is written using python sphinx. The source files are stored in `doc` directory. Please see how to write the documentation at `doc/README.md`.
